@@ -507,12 +507,12 @@ verify_burn_folder (NcbSelection *selection,
         }
 
         if (! verify_source_location_contents (BURN_URI, size, &image_paths, error)) {
-                if (image_paths != NULL) {
+                if (image_paths) {
                         /* change the source type */
                         ncb_selection_set_source (selection, NCB_SELECTION_SOURCE_ISO, (char *)image_paths->data);
                         g_list_foreach (image_paths, (GFunc)g_free, NULL);
                         g_list_free (image_paths);
-                        return TRUE;
+                        return FALSE;
                 } else {
                         return FALSE;
                 }
